@@ -19,9 +19,9 @@ pub trait TDChatMemberStatus: Debug + RObject {}
 #[serde(untagged)]
 pub enum ChatMemberStatus {
   #[doc(hidden)] _Default(()),
-  /// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage voice chats. In supergroups and channels, there are more detailed options for administrator privileges
+  /// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage video chats. In supergroups and channels, there are more detailed options for administrator privileges
   Administrator(ChatMemberStatusAdministrator),
-  /// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a voice chat of the chat
+  /// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a video chat of the chat
   Banned(ChatMemberStatusBanned),
   /// The user is the owner of the chat and has all the administrator privileges
   Creator(ChatMemberStatusCreator),
@@ -133,7 +133,7 @@ impl AsRef<ChatMemberStatus> for ChatMemberStatus {
 
 
 
-/// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage voice chats. In supergroups and channels, there are more detailed options for administrator privileges
+/// The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage video chats. In supergroups and channels, there are more detailed options for administrator privileges
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusAdministrator {
   #[doc(hidden)]
@@ -164,8 +164,8 @@ pub struct ChatMemberStatusAdministrator {
   can_pin_messages: bool,
   /// True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them
   can_promote_members: bool,
-  /// True, if the administrator can manage voice chats
-  can_manage_voice_chats: bool,
+  /// True, if the administrator can manage video chats
+  can_manage_video_chats: bool,
   /// True, if the administrator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
   is_anonymous: bool,
   
@@ -213,7 +213,7 @@ impl ChatMemberStatusAdministrator {
 
   pub fn can_promote_members(&self) -> bool { self.can_promote_members }
 
-  pub fn can_manage_voice_chats(&self) -> bool { self.can_manage_voice_chats }
+  pub fn can_manage_video_chats(&self) -> bool { self.can_manage_video_chats }
 
   pub fn is_anonymous(&self) -> bool { self.is_anonymous }
 
@@ -294,8 +294,8 @@ impl RTDChatMemberStatusAdministratorBuilder {
   }
 
    
-  pub fn can_manage_voice_chats(&mut self, can_manage_voice_chats: bool) -> &mut Self {
-    self.inner.can_manage_voice_chats = can_manage_voice_chats;
+  pub fn can_manage_video_chats(&mut self, can_manage_video_chats: bool) -> &mut Self {
+    self.inner.can_manage_video_chats = can_manage_video_chats;
     self
   }
 
@@ -321,7 +321,7 @@ impl AsRef<ChatMemberStatusAdministrator> for RTDChatMemberStatusAdministratorBu
 
 
 
-/// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a voice chat of the chat
+/// The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a video chat of the chat
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMemberStatusBanned {
   #[doc(hidden)]
