@@ -13,6 +13,7 @@ pub use self::_common::{
 pub use self::account_ttl::*;
 pub use self::address::*;
 pub use self::animated_chat_photo::*;
+pub use self::animated_emoji::*;
 pub use self::animation::*;
 pub use self::animations::*;
 pub use self::audio::*;
@@ -61,6 +62,9 @@ pub use self::chat_invite_link_info::*;
 pub use self::chat_invite_link_member::*;
 pub use self::chat_invite_link_members::*;
 pub use self::chat_invite_links::*;
+pub use self::chat_join_request::*;
+pub use self::chat_join_requests::*;
+pub use self::chat_join_requests_info::*;
 pub use self::chat_list::*;
 pub use self::chat_lists::*;
 pub use self::chat_location::*;
@@ -82,12 +86,14 @@ pub use self::chat_statistics_administrator_actions_info::*;
 pub use self::chat_statistics_inviter_info::*;
 pub use self::chat_statistics_message_interaction_info::*;
 pub use self::chat_statistics_message_sender_info::*;
+pub use self::chat_theme::*;
 pub use self::chat_type::*;
 pub use self::chats::*;
 pub use self::chats_nearby::*;
 pub use self::check_chat_username_result::*;
 pub use self::check_sticker_set_name_result::*;
 pub use self::closed_vector_path::*;
+pub use self::color_replacement::*;
 pub use self::connected_website::*;
 pub use self::connected_websites::*;
 pub use self::connection_state::*;
@@ -124,6 +130,7 @@ pub use self::group_call_id::*;
 pub use self::group_call_participant::*;
 pub use self::group_call_participant_video_info::*;
 pub use self::group_call_recent_speaker::*;
+pub use self::group_call_video_quality::*;
 pub use self::group_call_video_source_group::*;
 pub use self::hashtags::*;
 pub use self::http_url::*;
@@ -167,6 +174,8 @@ pub use self::login_url_info::*;
 pub use self::mask_point::*;
 pub use self::mask_position::*;
 pub use self::message::*;
+pub use self::message_calendar::*;
+pub use self::message_calendar_day::*;
 pub use self::message_content::*;
 pub use self::message_copy_options::*;
 pub use self::message_file_type::*;
@@ -175,6 +184,8 @@ pub use self::message_forward_origin::*;
 pub use self::message_interaction_info::*;
 pub use self::message_link::*;
 pub use self::message_link_info::*;
+pub use self::message_position::*;
+pub use self::message_positions::*;
 pub use self::message_reply_info::*;
 pub use self::message_scheduling_state::*;
 pub use self::message_send_options::*;
@@ -251,6 +262,8 @@ pub use self::secret_chat_state::*;
 pub use self::session::*;
 pub use self::sessions::*;
 pub use self::shipping_option::*;
+pub use self::sponsored_message::*;
+pub use self::sponsored_messages::*;
 pub use self::statistical_graph::*;
 pub use self::statistical_value::*;
 pub use self::sticker::*;
@@ -284,6 +297,7 @@ pub use self::text_entities::*;
 pub use self::text_entity::*;
 pub use self::text_entity_type::*;
 pub use self::text_parse_mode::*;
+pub use self::theme_settings::*;
 pub use self::thumbnail::*;
 pub use self::thumbnail_format::*;
 pub use self::top_chat_category::*;
@@ -301,8 +315,8 @@ pub use self::validated_order_info::*;
 pub use self::vector_path_command::*;
 pub use self::venue::*;
 pub use self::video::*;
+pub use self::video_chat::*;
 pub use self::video_note::*;
-pub use self::voice_chat::*;
 pub use self::voice_note::*;
 pub use self::web_page::*;
 pub use self::web_page_instant_view::*;
@@ -313,6 +327,7 @@ pub use self::web_page_instant_view::*;
 mod account_ttl;
 mod address;
 mod animated_chat_photo;
+mod animated_emoji;
 mod animation;
 mod animations;
 mod audio;
@@ -361,6 +376,9 @@ mod chat_invite_link_info;
 mod chat_invite_link_member;
 mod chat_invite_link_members;
 mod chat_invite_links;
+mod chat_join_request;
+mod chat_join_requests;
+mod chat_join_requests_info;
 mod chat_list;
 mod chat_lists;
 mod chat_location;
@@ -382,12 +400,14 @@ mod chat_statistics_administrator_actions_info;
 mod chat_statistics_inviter_info;
 mod chat_statistics_message_interaction_info;
 mod chat_statistics_message_sender_info;
+mod chat_theme;
 mod chat_type;
 mod chats;
 mod chats_nearby;
 mod check_chat_username_result;
 mod check_sticker_set_name_result;
 mod closed_vector_path;
+mod color_replacement;
 mod connected_website;
 mod connected_websites;
 mod connection_state;
@@ -424,6 +444,7 @@ mod group_call_id;
 mod group_call_participant;
 mod group_call_participant_video_info;
 mod group_call_recent_speaker;
+mod group_call_video_quality;
 mod group_call_video_source_group;
 mod hashtags;
 mod http_url;
@@ -467,6 +488,8 @@ mod login_url_info;
 mod mask_point;
 mod mask_position;
 mod message;
+mod message_calendar;
+mod message_calendar_day;
 mod message_content;
 mod message_copy_options;
 mod message_file_type;
@@ -475,6 +498,8 @@ mod message_forward_origin;
 mod message_interaction_info;
 mod message_link;
 mod message_link_info;
+mod message_position;
+mod message_positions;
 mod message_reply_info;
 mod message_scheduling_state;
 mod message_send_options;
@@ -551,6 +576,8 @@ mod secret_chat_state;
 mod session;
 mod sessions;
 mod shipping_option;
+mod sponsored_message;
+mod sponsored_messages;
 mod statistical_graph;
 mod statistical_value;
 mod sticker;
@@ -584,6 +611,7 @@ mod text_entities;
 mod text_entity;
 mod text_entity_type;
 mod text_parse_mode;
+mod theme_settings;
 mod thumbnail;
 mod thumbnail_format;
 mod top_chat_category;
@@ -601,8 +629,8 @@ mod validated_order_info;
 mod vector_path_command;
 mod venue;
 mod video;
+mod video_chat;
 mod video_note;
-mod voice_chat;
 mod voice_note;
 mod web_page;
 mod web_page_instant_view;
